summaryrefslogtreecommitdiffstats
path: root/examples/listboxcombo
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2023-12-27 19:25:43 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2023-12-27 19:25:43 +0900
commitfb401a891f1b426e9419c0cb16403df407138611 (patch)
tree045b51949b3140039e37d898d8b0513016a86bea /examples/listboxcombo
parenta9d178f1000475ba1727ffe123a2c54585488c01 (diff)
downloadtqt3-fb401a891f1b426e9419c0cb16403df407138611.tar.gz
tqt3-fb401a891f1b426e9419c0cb16403df407138611.zip
Rename METHOD, SIGNAL, SLOT to TQ_METHOD, TQ_SIGNAL, TQ_SLOT
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
Diffstat (limited to 'examples/listboxcombo')
-rw-r--r--examples/listboxcombo/listboxcombo.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/examples/listboxcombo/listboxcombo.cpp b/examples/listboxcombo/listboxcombo.cpp
index 537ad1a9e..cf06c806d 100644
--- a/examples/listboxcombo/listboxcombo.cpp
+++ b/examples/listboxcombo/listboxcombo.cpp
@@ -85,8 +85,8 @@ ListBoxCombo::ListBoxCombo( TQWidget *parent, const char *name )
// Create a pushbutton...
TQPushButton *arrow1 = new TQPushButton( " -> ", row1 );
- // ...and connect the clicked SIGNAL with the SLOT slotLeft2Right
- connect( arrow1, SIGNAL( clicked() ), this, SLOT( slotLeft2Right() ) );
+ // ...and connect the clicked TQ_SIGNAL with the TQ_SLOT slotLeft2Right
+ connect( arrow1, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotLeft2Right() ) );
// create an empty single-selection ListBox
lb2 = new TQListBox( row1 );
@@ -131,12 +131,12 @@ ListBoxCombo::ListBoxCombo( TQWidget *parent, const char *name )
}
// Connect the activated SIGNALs of the Comboboxes with SLOTs
- connect( cb1, SIGNAL( activated( const TQString & ) ), this, SLOT( slotCombo1Activated( const TQString & ) ) );
- connect( cb2, SIGNAL( activated( const TQString & ) ), this, SLOT( slotCombo2Activated( const TQString & ) ) );
+ connect( cb1, TQ_SIGNAL( activated( const TQString & ) ), this, TQ_SLOT( slotCombo1Activated( const TQString & ) ) );
+ connect( cb2, TQ_SIGNAL( activated( const TQString & ) ), this, TQ_SLOT( slotCombo2Activated( const TQString & ) ) );
}
/*
- * SLOT slotLeft2Right
+ * TQ_SLOT slotLeft2Right
*
* Copies all selected items of the first ListBox into the
* second ListBox
@@ -161,7 +161,7 @@ void ListBoxCombo::slotLeft2Right()
}
/*
- * SLOT slotCombo1Activated( const TQString &s )
+ * TQ_SLOT slotCombo1Activated( const TQString &s )
*
* Sets the text of the item which the user just selected
* in the first Combobox (and is now the value of s) to
@@ -174,7 +174,7 @@ void ListBoxCombo::slotCombo1Activated( const TQString &s )
}
/*
- * SLOT slotCombo2Activated( const TQString &s )
+ * TQ_SLOT slotCombo2Activated( const TQString &s )
*
* Sets the text of the item which the user just selected
* in the second Combobox (and is now the value of s) to